@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::ChartPoint;
 use AsposeCellsCloud::Object::Link;
 use AsposeCellsCloud::Object::LinkElement; 
 
@@ -119,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents a collection that contains all the points in one series.',
                                   class => 'ChartPoints',
                                   required => [], # TODO
 }                                 );
@@ -127,9 +128,9 @@ __PACKAGE__->class_documentation({description => '',
 
 __PACKAGE__->method_documentation({
      'chart_point_list' => {
-     	datatype => 'ARRAY[LinkElement]',
+     	datatype => 'ARRAY[ChartPoint]',
      	base_name => 'ChartPointList',
-     	description => '',
+     	description => 'This class has a property named ChartPointList of type List ChartPoint  with an XmlElement attribute "ChartPoint".',
      	format => '',
      	read_only => '',
      		},
@@ -143,7 +144,7 @@ __PACKAGE__->method_documentation({
 });
 
 __PACKAGE__->swagger_types( {
-    'chart_point_list' => 'ARRAY[LinkElement]',
+    'chart_point_list' => 'ARRAY[ChartPoint]',
     'link' => 'Link' 
 } );
 
