@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'I`m happy to help! Could you please provide me with the features you would like me to summarize into a class summary?',
                                   class => 'ImportCSVDataOption',
                                   required => [], # TODO
 }                                 );
@@ -131,7 +131,7 @@ __PACKAGE__->method_documentation({
      'separator_string' => {
      	datatype => 'string',
      	base_name => 'SeparatorString',
-     	description => '',
+     	description => 'A property named SeparatorString of type string that can be accessed and modified publicly.',
      	format => '',
      	read_only => '',
      		},
