@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents a list box object.',
                                   class => 'ListBox',
                                   required => [], # TODO
 }                                 );
@@ -131,7 +131,7 @@ __PACKAGE__->method_documentation({
      'input_range' => {
      	datatype => 'string',
      	base_name => 'InputRange',
-     	description => '',
+     	description => 'This property stores the input range for the class.',
      	format => '',
      	read_only => '',
      		},
