@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -120,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents options of saving pdf file.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'PdfSaveOptions',
                                   required => [], # TODO
 }                                 );
@@ -130,133 +130,133 @@ __PACKAGE__->method_documentation({
      'display_doc_title' => {
      	datatype => 'boolean',
      	base_name => 'DisplayDocTitle',
-     	description => 'Indicates whether the window`s title bar should display the document title.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'export_document_structure' => {
      	datatype => 'boolean',
      	base_name => 'ExportDocumentStructure',
-     	description => 'Indicates whether to export document structure.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'emf_render_setting' => {
      	datatype => 'string',
      	base_name => 'EmfRenderSetting',
-     	description => 'Setting for rendering Emf metafile.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'custom_properties_export' => {
      	datatype => 'string',
      	base_name => 'CustomPropertiesExport',
-     	description => 'Specifies the way CustomDocumentPropertyCollection are exported to PDF file.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'optimization_type' => {
      	datatype => 'string',
      	base_name => 'OptimizationType',
-     	description => 'Gets and sets pdf optimization type.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'producer' => {
      	datatype => 'string',
      	base_name => 'Producer',
-     	description => 'Gets and sets producer of generated pdf document.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'pdf_compression' => {
      	datatype => 'string',
      	base_name => 'PdfCompression',
-     	description => 'Indicate the compression algorithm.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'font_encoding' => {
      	datatype => 'string',
      	base_name => 'FontEncoding',
-     	description => 'Gets or sets embedded font encoding in pdf.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'watermark' => {
      	datatype => 'RenderingWatermark',
      	base_name => 'Watermark',
-     	description => 'Gets or sets watermark to output.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'calculate_formula' => {
      	datatype => 'boolean',
      	base_name => 'CalculateFormula',
-     	description => 'Indicates whether calculate formulas before saving pdf file.The default value is false.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'check_font_compatibility' => {
      	datatype => 'boolean',
      	base_name => 'CheckFontCompatibility',
-     	description => 'Indicates whether check font compatibility for every character in text.                The default value is true.  Disable this property may give better performance.                 But when the default or specified font of text/character cannot be used                to render it, unreadable characters(such as block) maybe occur in the generated                pdf.  For such situation user should keep this property as true so that alternative                font can be searched and used to render the text instead;',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'compliance' => {
      	datatype => 'string',
      	base_name => 'Compliance',
-     	description => 'Workbook converts to pdf will according to PdfCompliance in this property.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'default_font' => {
      	datatype => 'string',
      	base_name => 'DefaultFont',
-     	description => 'When characters in the Excel are unicode and not be set with correct font in cell style,              They may appear as block in pdf,image.  Set the DefaultFont such as MingLiu or MS Gothic to show these characters.               If this property is not set, Aspose.Cells will use system default font to show these unicode characters.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'one_page_per_sheet' => {
      	datatype => 'boolean',
      	base_name => 'OnePagePerSheet',
-     	description => 'If OnePagePerSheet is true , all content of one sheet will output to only            one page in result. The paper size of pagesetup will be invalid, and the               other settings of pagesetup will still take effect.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'printing_page_type' => {
      	datatype => 'string',
      	base_name => 'PrintingPageType',
-     	description => 'Indicates which pages will not be printed.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'security_options' => {
      	datatype => 'PdfSecurityOptions',
      	base_name => 'SecurityOptions',
-     	description => 'Set this options, when security is need in xls2pdf result.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'desired_ppi' => {
      	datatype => 'int',
      	base_name => 'desiredPPI',
-     	description => 'Set desired PPI(pixels per inch) of resample images and jpeg quality  All images will be converted to JPEG with the specified quality setting, and images that are greater than the specified PPI (pixels per inch) will be resampled.              Desired pixels per inch. 220 high quality. 150 screen quality. 96 email quality.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'jpeg_quality' => {
      	datatype => 'int',
      	base_name => 'jpegQuality',
-     	description => 'Set desired PPI(pixels per inch) of resample images and jpeg quality  All images will be converted to JPEG with the specified quality setting, and images that are greater than the specified PPI (pixels per inch) will be resampled.              0 - 100% JPEG quality.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'image_type' => {
      	datatype => 'string',
      	base_name => 'ImageType',
-     	description => 'Represents the image type when converting the chart and shape .',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
@@ -314,6 +314,41 @@ __PACKAGE__->method_documentation({
      	base_name => 'ValidateMergedAreas',
      	description => '',
      	format => '',
+     	read_only => '',
+     		},
+     'merge_areas' => {
+     	datatype => 'boolean',
+     	base_name => 'MergeAreas',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'sort_external_names' => {
+     	datatype => 'boolean',
+     	base_name => 'SortExternalNames',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'check_excel_restriction' => {
+     	datatype => 'boolean',
+     	base_name => 'CheckExcelRestriction',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'update_smart_art' => {
+     	datatype => 'boolean',
+     	base_name => 'UpdateSmartArt',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'encrypt_document_properties' => {
+     	datatype => 'boolean',
+     	base_name => 'EncryptDocumentProperties',
+     	description => '',
+     	format => '',
      	read_only => '',
      		},    
 });
@@ -345,7 +380,12 @@ __PACKAGE__->swagger_types( {
     'enable_http_compression' => 'boolean',
     'refresh_chart_cache' => 'boolean',
     'sort_names' => 'boolean',
-    'validate_merged_areas' => 'boolean' 
+    'validate_merged_areas' => 'boolean',
+    'merge_areas' => 'boolean',
+    'sort_external_names' => 'boolean',
+    'check_excel_restriction' => 'boolean',
+    'update_smart_art' => 'boolean',
+    'encrypt_document_properties' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -375,7 +415,12 @@ __PACKAGE__->attribute_map( {
     'enable_http_compression' => 'EnableHTTPCompression',
     'refresh_chart_cache' => 'RefreshChartCache',
     'sort_names' => 'SortNames',
-    'validate_merged_areas' => 'ValidateMergedAreas' 
+    'validate_merged_areas' => 'ValidateMergedAreas',
+    'merge_areas' => 'MergeAreas',
+    'sort_external_names' => 'SortExternalNames',
+    'check_excel_restriction' => 'CheckExcelRestriction',
+    'update_smart_art' => 'UpdateSmartArt',
+    'encrypt_document_properties' => 'EncryptDocumentProperties' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
