@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -64,7 +65,8 @@ sub new {
 # PostExportRequest.format : The conversion format(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers).  ,
 # PostExportRequest.password : The password needed to open an Excel file.  ,
 # PostExportRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
-# PostExportRequest.region : The regional settings for workbook.   
+# PostExportRequest.region : The regional settings for workbook.  ,
+# PostExportRequest.FontsLocation : Use Custom fonts.   
 
 {
     my $params = {
@@ -87,7 +89,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/export';
+    my $_resource_path = 'v3.0/cells/export';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -119,16 +121,21 @@ sub run_http_request {
 
     if(defined $self->region){
         $query_params->{'region'} = $client->to_query_value($self->region);      
+    }
+
+    if(defined $self->fonts_location){
+        $query_params->{'FontsLocation'} = $client->to_query_value($self->fonts_location);      
     } 
     my $_body_data;
- 
+
 
     if (defined $self->file) {   
         my $map_file = $self->file;
         while ( my ($filename,$value) = each( %$map_file ) ) {
                 $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
         }
-    } 
+    }
+ 
 
     # authentication setting, if any
     my $auth_settings = [qw()];
@@ -180,6 +187,13 @@ __PACKAGE__->method_documentation({
      	base_name => 'region',
      	description => 'The regional settings for workbook.',
      	format => '',
+     	read_only => '',
+     		},
+     'fonts_location' => {
+     	datatype => 'string',
+     	base_name => 'FontsLocation',
+     	description => 'Use Custom fonts.',
+     	format => '',
      	read_only => '',
      		},    
 });
@@ -191,7 +205,8 @@ __PACKAGE__->attribute_map( {
     'format' => 'format',
     'password' => 'password',
     'check_excel_restriction' => 'checkExcelRestriction',
-    'region' => 'region' 
+    'region' => 'region',
+    'fonts_location' => 'FontsLocation' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
