@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -87,7 +88,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/metadata/update';
+    my $_resource_path = 'v3.0/cells/metadata/update';
 
     my $_method = 'POST';
     my $query_params = {};
@@ -119,18 +120,20 @@ sub run_http_request {
     my $_body_data;
 
 
+    # body params
+    if (defined $self->cells_documents) {
+         $_body_data = JSON->new->convert_blessed->encode( $self->cells_documents);
+         $form_params->{'cellsDocuments'} = [JSON->new->convert_blessed->encode( $self->cells_documents) ,'cellsDocuments','application/octet-stream'];
+    }
+
     if (defined $self->file) {   
         my $map_file = $self->file;
         while ( my ($filename,$value) = each( %$map_file ) ) {
                 $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
         }
-    } 
-
-    # body params
-    if (defined $self->cells_documents) {
-        #$_body_data = $self->cells_documents;
-         $_body_data = JSON->new->convert_blessed->encode( $self->cells_documents);
     }
+ 
+
     # authentication setting, if any
     my $auth_settings = [qw()];
 
