@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -62,6 +63,7 @@ sub new {
 # PutWorksheetBackgroundRequest.name : The file name.  ,
 # PutWorksheetBackgroundRequest.sheetName : The worksheet name.  ,
 # PutWorksheetBackgroundRequest.picPath : picture full filename.  ,
+# PutWorksheetBackgroundRequest.imageAdaptOption :   ,
 # PutWorksheetBackgroundRequest.folder : The folder where the file is situated.  ,
 # PutWorksheetBackgroundRequest.storageName : The storage name where the file is situated.  ,
 # PutWorksheetBackgroundRequest.File : File to upload   
@@ -87,7 +89,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/{name}/worksheets/{sheetName}/background';
+    my $_resource_path = 'v3.0/cells/{name}/worksheets/{sheetName}/background';
 
     my $_method = 'PUT';
     my $query_params = {};
@@ -115,6 +117,10 @@ sub run_http_request {
         $query_params->{'picPath'} = $client->to_query_value($self->pic_path);      
     }
 
+    if(defined $self->image_adapt_option){
+        $query_params->{'imageAdaptOption'} = $client->to_query_value($self->image_adapt_option);      
+    }
+
     if(defined $self->folder){
         $query_params->{'folder'} = $client->to_query_value($self->folder);      
     }
@@ -123,14 +129,15 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
- 
+
 
     if (defined $self->file) {   
         my $map_file = $self->file;
         while ( my ($filename,$value) = each( %$map_file ) ) {
                 $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
         }
-    } 
+    }
+ 
 
     # authentication setting, if any
     my $auth_settings = [qw()];
@@ -163,6 +170,13 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
+     'image_adapt_option' => {
+     	datatype => 'string',
+     	base_name => 'imageAdaptOption',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
@@ -191,6 +205,7 @@ __PACKAGE__->attribute_map( {
     'name' => 'name',
     'sheet_name' => 'sheetName',
     'pic_path' => 'picPath',
+    'image_adapt_option' => 'imageAdaptOption',
     'folder' => 'folder',
     'storage_name' => 'storageName',
     'file' => 'File' 
