@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use File::Basename;
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -84,7 +85,7 @@ sub run_http_request {
     my $client = $args{'client'};
 
     # parse inputs
-    my $_resource_path = '/cells/storage/file/{path}';
+    my $_resource_path = 'v4.0/cells/storage/file/{path}';
 
     my $_method = 'PUT';
     my $query_params = {};
@@ -106,14 +107,10 @@ sub run_http_request {
         $query_params->{'storageName'} = $client->to_query_value($self->storage_name);      
     } 
     my $_body_data;
- 
 
-    if (defined $self->upload_files) {   
-        my $map_file = $self->upload_files;
-        while ( my ($filename,$value) = each( %$map_file ) ) {
-                $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
-        }
-    } 
+
+    $form_params->{basename($self->upload_files)} = [$self->upload_files ,basename($self->upload_files),'application/octet-stream'];
+ 
 
     # authentication setting, if any
     my $auth_settings = [qw()];
