@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2024 Aspose.Cells Cloud
+Copyright (c) 2025 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -61,8 +61,8 @@ has version_info => ( is => 'ro',
                       isa => 'HashRef',
                       default => sub { {
                           app_name => 'Aspose.Cells Cloud SDK APIs.',
-                          app_version => '24.9',
-                          generator_class => 'io.swagger.codegen.languages.PerlClientCodegen',
+                          app_version => '25.6.1',
+                          generator_class => 'io.swagger.codegen.languages.PerlClientCodeGen',
                       } },
                       documentation => 'Information about the application version and the codegen codebase version'
                       );
@@ -119,16 +119,16 @@ sub _build_af {
 
 AsposeCellsCloud::Role - a Moose role for the Aspose.Cells Cloud SDK APIs.
 
-=head2 Aspose.Cells Cloud SDK APIs. version: 24.9
+=head2 Aspose.Cells Cloud SDK APIs. version: 25.6.1
 
 =head1 VERSION
 
-Automatically generated by the Perl Swagger Codegen project:
+Automatically generated by the Perl Swagger CodeGen project:
 
 =over 4
-=item Build package: io.swagger.codegen.languages.PerlClientCodegen
+=item Build package: io.swagger.codegen.languages.PerlClientCodeGen
 
-=item Codegen version:
+=item CodeGen version:
 
 =back
 
@@ -139,7 +139,7 @@ AsposeCellsCloud::ApiFactory for non-Moosey usage.
 
 =head1 SYNOPSIS
 
-The Perl Swagger Codegen project builds a library of Perl modules to interact with
+The Perl Swagger CodeGen project builds a library of Perl modules to interact with
 a web service defined by a OpenAPI Specification. See below for how to build the
 library.
 
